/*
 * Copyright (C) 2020-2023 David Sugar <tychosoft@gmail.com>.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef FEATURES_HPP_
#define FEATURES_HPP_

#include "events.hpp"
#include "registry.hpp"
#include "utils.hpp"
#include "exosip.hpp"

#include <ctime>

namespace server {
struct feature_data {
    std::string code;           // as dialed
    mutable std::string name;   // name of feature
    mutable std::string extra;  // extra digits if any
    registry server, origin;
    bool sysop{false};
};
using feature_t = const std::shared_ptr<const feature_data>;

void exec_features(const keyfile& config);

// messages component dispatch actions
namespace exec {
void stop_features();
void reload_features(const keyfile& config);
void dialed_feature(feature_t feature, const event_t &event);
}} // end namespace

/*!
 * Feature code handling.
 * \file features.hpp
 */
#endif
