/*
 * Copyright (C) 2020-2023 David Sugar <tychosoft@gmail.com>.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef UTILS_HPP
#define UTILS_HPP

#include "compiler.hpp"

#include <string>
#include <ctime>
#include <cstdint>

namespace server {
class event_t;
}

namespace server::util {
auto idverify(const char *cp, size_t max) -> size_t;
auto u8verify(const char *cp, size_t max = 255) -> size_t;
auto u8verify(std::string_view view) -> size_t;
auto get_env(const char *id, size_t max = FILENAME_MAX) -> const char *;
auto get_value(std::string_view text) -> int;
auto get_count(std::string_view count) -> uint32_t;
auto get_port(const char *cp, uint16_t port = 0) -> uint16_t;
auto get_period(const char *cp, unsigned period = 0) -> unsigned;
auto get_expires(std::string_view cp) -> time_t;
auto sha256_secret(std::string_view userid, std::string_view realm, std::string_view secret) -> std::string;
auto sha256_digest(std::string_view secret, const event_t& event) -> std::string;
auto md5_secret(std::string_view userid, std::string_view realm, std::string_view secret) -> std::string;
auto md5_digest(std::string_view secret, const event_t& event) -> std::string;
auto is_bool(std::string value) -> bool;
auto is_true(std::string_view value) -> bool;
auto set_priority(int priority) -> bool;
} // end namespace

/*!
 * Utility functions and support for server.
 * \file utils.hpp
 */
#endif
